#!/bin/env perl

use strict;
use warnings;
use LATMOS::Accounts;
use Getopt::Long;
use Pod::Usage;
use LATMOS::Accounts::Utils;
use LATMOS::Accounts::Log;
use GraphViz;

=head1 NAME

    la-group -- Graph user/cells-department

=head1 SYNOPSIS

    la-group [options]

=cut

GetOptions(
    'c|config=s' => \my $config,
    'b|base=s'   => \my $base,
    'help'       => sub { pod2usage(0) },
) or pod2usage();

=head1 OPTIONS

=over 4

=item -c|--config configfile

Use this configuration file instead the default one

=item -b|--base basename

Query this specific base instead default.

=back

=cut

my $LA = LATMOS::Accounts->new($config, noacl => 1);
my $labase = $base ? $LA->base($base) : $LA->default_base;
$labase && $labase->load or die "Cannot load base";

my $g = GraphViz->new(
    layout => 'neato',
    concentrate => 1,
    overlap => 'compress',
    ratio => 'compress',
);

open(my $h, '>', 'graph.png') or die 'cannot open graph';

#foreach ($labase->list_objects('user')) {
#    $g->add_node($_);
#}

my %users;

foreach my $gr ($labase->list_objects('group')) {
    my $o = $labase->get_object('group', $gr);
    ($o->get_c_field('sutype') || '') =~ /^(dpmt|cell)$/ or next;
    $g->add_node($gr,fillcolor => 'red', style => 'filled');
    foreach ($o->get_attributes('member')) {
        $users{$_} or do {
            $users{$_} = 1;
            $g->add_node($_);
        };
        warn "$_ => $gr";
        $g->add_edge($_ => $gr);
    }
}

print $h $g->as_png;
close($h);
